%define anolis_release 5
# When bootstrapping new Python we need to build flit in bootstrap mode.
# The Python RPM dependency generators and pip are not yet available.
# When building in bootstrap mode, only flit-core is built.
%bcond_with bootstrap

# Tests are enabled by default, unless we bootstrap.
# Disable them to avoid a circular build dependency on requests-download and testpath.
%bcond_without tests 

%global srcname flit

Name:		python-%{srcname}
Version:	3.8.0
Release:	%{anolis_release}%{?dist}
Summary:	Simplified packaging of Python modules

# ./flit/log.py under ASL 2.0 license
# ./flit/upload.py under PSF license
License:	BSD and ASL 2.0 and Python

URL:		https://flit.readthedocs.io/en/latest/
Source0:	https://github.com/takluyver/flit/archive/%{version}/%{srcname}-%{version}.tar.gz

# For the tests
Source1:	https://pypi.org/pypi?%3Aaction=list_classifiers#/classifiers.lst

BuildArch:	noarch
BuildRequires:	python3-devel
BuildRequires:  python3-tomli
%if %{without bootstrap}
BuildRequires:  pyproject-rpm-macros
BuildRequires:	python3-pip
%endif

%if %{with tests}
# Runtime deps, others
BuildRequires:	python3-requests
BuildRequires:	python3-docutils
BuildRequires:	python3-pygments
BuildRequires:	python3-tomli-w

# Test deps
BuildRequires:	/usr/bin/python
BuildRequires:	python3-pytest
BuildRequires:	python3-responses
BuildRequires:	git-core

# Test deps that require flit to build:
BuildRequires:	python3-testpath
BuildRequires:	python3-requests-download
%endif

%global _description %{expand:
Flit is a simple way to put Python packages and modules on PyPI.

Flit only creates packages in the new 'wheel' format. People using older
versions of pip (<1.5) or easy_install will not be able to install them.

Flit packages a single importable module or package at a time, using the import
name as the name on PyPI. All sub-packages and data files within a package are
included automatically.

Flit requires Python 3, but you can use it to distribute modules for Python 2,
so long as they can be imported on Python 3.}

%description %_description


%if %{without bootstrap}
%package -n python3-%{srcname}
Summary:	%{summary}
Requires:	python3-%{srcname}-core = %{version}-%{release}

# https://pypi.python.org/pypi/tornado
# ./flit/log.py unknown version
Provides:	bundled(python3dist(tornado))

# soft dependency: (WARNING) Cannot analyze code. Pygments package not found.
Recommends:	python3-pygments

%description -n python3-%{srcname} %_description

%package -n     python3-%{srcname}-doc
Summary:        doc files for python3-%{srcname}
Requires:       python3-%{srcname} = %{version}-%{release}

%description -n python3-%{srcname}-doc
doc files for python3-%{srcname}

%endif


%package -n python3-%{srcname}-core
Summary:	PEP 517 build backend for packages using Flit
Conflicts:	python3-%{srcname} < 2.1.0-2

# RPM generators are not yet available when we bootstrap
%if %{with bootstrap}
Provides:       python%{python3_pkgversion}dist(flit-core) = %{version}
Provides:       python%{python3_version}dist(flit-core) = %{version}
Requires:       python(abi) = %{python3_version}
%else
Requires:       (python3-tomli if python(abi) < 3.11)
%endif

%description -n python3-%{srcname}-core
This provides a PEP 517 build backend for packages using Flit.
The only public interface is the API specified by PEP 517,
at flit_core.buildapi.


%prep
%autosetup -p1 -n %{srcname}-%{version}

# Remove vendored tomli that flit_core includes to solve the circular dependency on older Pythons
# (flit_core requires tomli, but flit_core is needed to build tomli).
# We don't use this, as tomllib is a part of standard library since Python 3.11.
rm -rf flit_core/flit_core/vendor

%if %{without bootstrap}
%generate_buildrequires
%pyproject_buildrequires
%endif

%build
export FLIT_NO_NETWORK=1

# first, build flit_core with self
cd flit_core
%if %{with bootstrap}
%{python3} -m flit_core.wheel
%else
%pyproject_wheel
cd -

# build of the main flit (needs flit_core)
export PYTHONPATH=$PWD:$PWD/flit_core
%pyproject_wheel
%endif

%install
%if %{with bootstrap}
cd flit_core
%{python3} bootstrap_install.py --install-root %{buildroot} dist/flit_core-%{version}-py3-none-any.whl
# for consistency with %%pyproject_install:
rm %{buildroot}%{python3_sitelib}/flit_core-*.dist-info/RECORD
%else
%pyproject_install
%endif

# don't ship tests in flit_core package
# if upstream decides to change the installation, it can be removed:
# https://github.com/takluyver/flit/issues/403
rm -r %{buildroot}%{python3_sitelib}/flit_core/tests/

%if %{with tests}
%check
# flit attempts to download list of classifiers from PyPI, but not if it's cached
# test_invalid_classifier fails without the list
mkdir -p fake_cache/flit
cp %{SOURCE1} fake_cache/flit
export XDG_CACHE_HOME=$PWD/fake_cache

%pytest
%endif


%if %{without bootstrap}
%files -n python3-%{srcname}
%license LICENSE
%{python3_sitelib}/flit-*.dist-info/
%{python3_sitelib}/flit/
%{_bindir}/flit

%files -n python3-%{srcname}-doc
%doc README.rst

%endif


%files -n python3-%{srcname}-core
%license LICENSE
%doc flit_core/README.rst
%{python3_sitelib}/flit_core-*.dist-info/
%{python3_sitelib}/flit_core/


%changelog
* Fri May 05 2023 Funda Wang <fundawang@yeah.net> - 3.8.0-5
- Enable tests

* Wed May 03 2023 Funda Wang <fundawang@yeah.net> - 3.8.0-4
- Promote tomli if python < 3.11

* Sat Apr 22 2023 Funda Wang <fundawang@yeah.net> - 3.8.0-3
- Disable bootstrap and tests

* Mon Mar 06 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.8.0-2
- disable bootstrap

* Tue Feb 28 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.8.0-1
- Init upstream from 3.8.0
